@@ -27,7 +27,7 @@
 
 #include <KLineEdit>
 #include <KLocalizedString>
-#include <KRecursiveFilterProxyModel>
+#include <QSortFilterProxyModel>
 
 #include <KTextEditor/Document>
 #include <KTextEditor/MainWindow>
@@ -160,7 +160,7 @@ class LSPClientSymbolViewImpl : public QObject, public LSPClientSymbolView
     // last outline model we constructed
     std::shared_ptr<QStandardItemModel> m_outline;
     // filter model, setup once
-    KRecursiveFilterProxyModel m_filterModel;
+    QSortFilterProxyModel m_filterModel;
 
     // cached icons for model
     const QIcon m_icon_pkg = QIcon::fromTheme(QStringLiteral("code-block"));
@@ -202,6 +202,7 @@ public:
         m_filterModel.setFilterCaseSensitivity(Qt::CaseInsensitive);
         m_filterModel.setSortCaseSensitivity(Qt::CaseInsensitive);
         m_filterModel.setSourceModel(m_outline.get());
+        m_filterModel.setRecursiveFilteringEnabled(true);
         m_symbols->setModel(&m_filterModel);
         delete m;
 
@@ -314,10 +315,11 @@ public:
             }
 
             auto node = new QStandardItem();
+            auto line = new QStandardItem();
             if (parent && tree)
-                parent->appendRow(node);
+                parent->appendRow({node, line});
             else
-                model->appendRow(node);
+                model->appendRow({node, line});
 
             if (!symbol.detail.isEmpty())
                 details = true;
@@ -325,6 +327,8 @@ public:
             node->setText(symbol.name + detail);
             node->setIcon(*icon);
             node->setData(QVariant::fromValue<KTextEditor::Range>(symbol.range), Qt::UserRole);
+            static const QChar prefix = QChar::fromLatin1('0');
+            line->setText(QStringLiteral("%1").arg(symbol.range.start().line(), 7, 10, prefix));
             // recurse children
             makeNodes(symbol.children, tree, show_detail, model, node, details);
         }
@@ -381,8 +385,13 @@ public:
             m_symbols->setSortingEnabled(true);
             m_symbols->sortByColumn(0, Qt::AscendingOrder);
         } else {
-            m_symbols->sortByColumn(-1, Qt::AscendingOrder);
+            // most servers provide items in reasonable file/input order
+            // however sadly not all, so let's sort by hidden line number column to make sure
+            m_symbols->setSortingEnabled(true);
+            m_symbols->sortByColumn(1, Qt::AscendingOrder);
         }
+        // no need to show internal info
+        m_symbols->setColumnHidden(1, true);
 
         // handle auto-expansion
         if (m_expandOn->isChecked()) {
@@ -396,10 +405,6 @@ public:
         // (as an indication there is nothing to show anyway)
         m_detailsOn->setEnabled(details);
 
-        // hide detail column if not needed/wanted
-        bool showDetails = m_detailsOn->isChecked() && details;
-        m_symbols->setColumnHidden(1, !showDetails);
-
         // current item tracking
         updateCurrentTreeItem();
     }
@@ -434,7 +439,9 @@ public:
                 m_models.move(it - m_models.begin(), 0);
                 auto &model = m_models.front();
                 // re-use if possible
-                if (revision == model.revision && model.model) {
+                // reloaded document recycles revision number, so avoid stale cache
+                // (clear := view switch)
+                if (revision == model.revision && model.model && (clear || revision > 0)) {
                     setModel(model.model);
                     return;
                 }
@@ -446,7 +453,7 @@ public:
                 }
             }
 
-            server->documentSymbols(view->document()->url(), this, utils::mem_fun(&self_type::onDocumentSymbols, this));
+            m_handle = server->documentSymbols(view->document()->url(), this, utils::mem_fun(&self_type::onDocumentSymbols, this));
 
             return;
         }
